@@ -30,7 +30,7 @@
 #include "SpectrumAnalyzer.h"
 #include "ListViewDelegate.h"
 #include "OssoWrapper.h"
-#include "MCEWrapper.h"
+#include "DBusWrapper.h"
 #include "global_defs.h"
 
 //defines
@@ -51,11 +51,13 @@ class QueueView : public QMainWindow
 
 public:
 
-    QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, MCEWrapper *pMCEWrapper, QWidget* parent = 0); //constructor
+    QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, DBusWrapper *pDBusWrapper, QWidget* parent = 0); //constructor
     ~QueueView();
 
     void setQueueInitialState(QList<Spotify::Track*> queue, qint32 currQueuePos); //public method for setting the initial playqueue view state
 
+    void setPauseOnHSUnplugged(bool state); //public method for setting the headset unplugged state (i.e., whether playback should be paused when headset is unplugged)
+
     virtual void show(); //overriden show method
 
 
@@ -111,7 +113,7 @@ private:
 
     OssoWrapper* m_pOssoWrapper; //OssoWrapper instance pointer
 
-    MCEWrapper* m_pMCEWrapper; //MCE D-bus interface wrapper
+    DBusWrapper* m_pDBusWrapper; //D-bus interface wrapper
 
     Spotify::Track* m_pCurrTrack; //currently playing track in queue
 
@@ -135,6 +137,8 @@ private:
 
     bool m_currTrackScrobbled; //TRUE in case the current track has been scrobbled (to Last.fm)
 
+    bool m_pauseOnHsetUnplugged; //TRUE in case playback should be paused when headset is unplugged
+
     qint32 m_CallerID; //used as identifier to Spotify session calls that require caller ID
 
     QList<Spotify::Track*> m_PlayQueue; //current play queue
@@ -188,6 +192,9 @@ private slots:
     void OnAlbumBrowseReady(Spotify::AlbumBrowser* browser, qint32 callerID);
     void OnOrientationChanged(); //device orientation changed (e.g, screen rotate)
     void OnDisplayStateChanged(bool state); //display state changed notification (true=ON, false=OFF)
+    //void OnProgressSliderClicked(int pos); //progress slider has been clicked (pos=clicked position)
+    void OnHalButtonPressed(const QString& value); //button pressed notification (condition) received from HAL (device)
+    void OnHeadsetRemoved(); //headset removed notification from Hal device manager received
 
 signals:
 
