@@ -32,6 +32,7 @@
 #define ENABLE_SCROBBLING_DEFAULT 0
 #define ORIENTATION_DEFAULT 0
 #define PLAYLIST_LOADING_TO_DEFAULT 30
+#define PAUSE_ON_HEADSET_UNPLUG_DEFAULT 0
 
 
 class SettingsDialog : public QDialog
@@ -97,6 +98,8 @@ private:
     QLabel m_PlaylistLoadingTOCaption;
     QLineEdit m_PlaylistLoadingTOInput; //timeout value for playlist loading (in secs)
 
+    QCheckBox m_PauseOnHSDisconnSelection; //selection to enable automatic pausing of music playback in case headset is unplugged
+
     QCheckBox m_EnableScrobblingSelection; //enable / disable scrobbling to Last.Fm
 
     QLabel m_LastFMUserIDCaption;
@@ -123,6 +126,8 @@ private:
 
     qint32 m_playlistLoadingTO;
 
+    qint32 m_pauseOnHsetUnplugged;
+
     qint32 m_enableScrobbling;
 
     QString m_strLastFMUserID;
