@@ -1,11 +1,20 @@
 #include <QtGui/QApplication>
 #include <QDBusError>
+#include <QTranslator>
 #include <QDBusConnection>
+#include <QLocale>
 #include "mainwindow.h"
 
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
+
+    //set up localisation
+
+    QTranslator appTranslator;
+    appTranslator.load("/opt/qspot/translations/qspot_" + QLocale::system().name());
+    a.installTranslator(&appTranslator);
+
    if (!QDBusConnection::sessionBus().isConnected()) {
     qWarning("Cannot connect to the D-Bus session bus.");
     exit(1);
