@@ -30,10 +30,12 @@ MainWindow::MainWindow(QWidget *parent)
         m_pOssoWrapper->requestPlaybackStateChange(PB_STATE_STOP); //request to enter initial stopped state
     }
 
-    m_pMCEWrapper = new MCEWrapper(this); //allocate MCE D-bus interface wrapper
-    if(m_pMCEWrapper)
+    m_pDBusWrapper = new DBusWrapper(this); //allocate D-bus interface wrapper
+    if(m_pDBusWrapper)
     {
-        connect(m_pMCEWrapper,SIGNAL(onDisplayStateChange(bool)),SLOT(OnDisplayStateChanged(bool)));
+        m_pDBusWrapper->enableHWZoomKeys(); //enable / grab control of the HW zoom controls (for volume control when phone is locked)
+        connect(m_pDBusWrapper,SIGNAL(onDisplayStateChange(bool)),SLOT(OnDisplayStateChanged(bool)));
+        connect(m_pDBusWrapper,SIGNAL(onZoomKeyPressed(quint32)),SLOT(OnHWZoomKeyPressed(quint32)));
     }
 
     m_pLastFMScrobbler = new LastFMScrobbler(this); //allocate Last.fm scrobbler instance
@@ -71,7 +73,7 @@ MainWindow::MainWindow(QWidget *parent)
     m_pAlbumView = new AlbumView(m_pSession,m_pTrackView);
     connect(m_pAlbumView,SIGNAL(playQueueSet(const QList<Spotify::Track*>&,qint32)),SLOT(OnSetPlayQueue(const QList<Spotify::Track*>&,qint32)));
 
-    m_pQueueView = new QueueView(m_pSession,m_pOssoWrapper,m_pMCEWrapper,this); //initial parent set to current instance
+    m_pQueueView = new QueueView(m_pSession,m_pOssoWrapper,m_pDBusWrapper,this); //initial parent set to current instance
     connect(m_pQueueView,SIGNAL(playQueuePosUpdated(qint32)),SLOT(OnPlayQueuePosUpdated(qint32)));
     connect(m_pQueueView,SIGNAL(playQueueSet(QList<Spotify::Track*>,qint32)),SLOT(OnSetPlayQueue(QList<Spotify::Track*>,qint32)));
     connect(m_pQueueView,SIGNAL(showFMTransmitterDialog()),SLOT(OnDisplayFMTransmitterDialog()));
@@ -117,15 +119,15 @@ MainWindow::MainWindow(QWidget *parent)
     m_SearchInput.setInputMethodHints(Qt::ImhNoAutoUppercase); //no auto-uppercase mode
     m_SearchInput.setDisabled(true);
 
-    m_SearchBtn.setStyleSheet("QPushButton {min-width: 78px; min-height: 48px; max-width: 78px; max-height: 48px;border-style: none; background-image: url(/usr/share/images/icon-search.png);}"
-                              "QPushButton:pressed {background-image: url(/usr/share/images/icon-search-on.png);}");
+    m_SearchBtn.setStyleSheet("QPushButton {min-width: 78px; min-height: 48px; max-width: 78px; max-height: 48px;border-style: none; background-image: url(/opt/qspot/images/icon-search.png);}"
+                              "QPushButton:pressed {background-image: url(/opt/qspot/images/icon-search-on.png);}");
     m_SearchBtn.setDisabled(true);
 
     m_pPlaylistModel->clear();
 
     QPixmap iconMap;
 
-    iconMap.load("/usr/share/images/icon-nowplaying.png"); //load icon from file
+    iconMap.load("/opt/qspot/images/icon-nowplaying.png"); //load icon from file
 
     m_NowPlayingIcon.setPixmap(iconMap); //set now playing icon
     m_NowPlayingIcon.setFixedSize(24,24);
@@ -163,18 +165,31 @@ MainWindow::MainWindow(QWidget *parent)
 void MainWindow::initAboutDialog()
 {
     //init the application about dialog
-    QPixmap appIconMap;
-    appIconMap.load("/usr/share/icons/hicolor/64x64/apps/qspot.png"); //load application icon from file
 
-    m_AboutDlg.setIconPixmap(appIconMap);
     m_AboutDlg.setWindowTitle(tr("About QSpot"));
+    m_AboutDlg.setIcon("/usr/share/icons/hicolor/64x64/apps/qspot.png");
     m_AboutDlg.setText(tr("QSpot version ") + APP_VERSION + "\n\n" + tr("An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).\n\n"
                         "(C) 2011 Andreas Enbacka and The QSpot Team.\n\n"
-                        "Special thanks to Markus (markusm@tmo) for assistance with the graphicla design and layout."));
+                        "Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout, "
+                        "and to Tomi (rantom@tmo) for the Finnish translations."));
+
+    QRect screenGeometry = QApplication::desktop()->screenGeometry(); // get current screen geometry
+    if (screenGeometry.width() > screenGeometry.height())
+    {//landscape mode
+        m_AboutDlg.setFixedSize(APP_WIDTH,APP_HEIGHT); //resize dialog to fixed size
+    }
+    else
+    {
+        m_AboutDlg.setFixedSize(APP_HEIGHT,APP_WIDTH); //resize dialog to fixed size
+    }
 }
 
 MainWindow::~MainWindow()
 {
+    if(m_pDBusWrapper)
+    {
+        m_pDBusWrapper->disableHWZoomKeys(); //release HW keypad (zoomkeys)
+    }
 }
 
 void MainWindow::OnDisplayFMTransmitterDialog()
@@ -191,6 +206,7 @@ void MainWindow::OnSettingsSaved()
 {
     //called when app settings have been saved (modified)  
 
+    //buffering related settings
     m_pSession->setMinBufferSize(m_pAppSettings->value("QSpot/minBufferLen",MIN_BUFFER_LEN_DEFAULT).toInt()); //update min. buffer length (default to 30 secs)
 
     if(m_pAppSettings->value("QSpot/preBufferingActive",PRE_BUFFERING_DEFAULT).toInt())
@@ -202,8 +218,16 @@ void MainWindow::OnSettingsSaved()
         m_pSession->setPreBufferingActive(false);
     }
 
+    //display orientation setting
     setDisplayOrientation(m_pAppSettings->value("QSpot/displayOrientation",ORIENTATION_DEFAULT).toInt());
 
+    //headset related settings
+    if(m_pAppSettings->value("QSpot/pauseOnHsetUnplugged",PAUSE_ON_HEADSET_UNPLUG_DEFAULT).toInt())
+        m_pQueueView->setPauseOnHSUnplugged(true);
+    else
+        m_pQueueView->setPauseOnHSUnplugged(false);
+
+    //scrobbling related settings
     if(m_pAppSettings->value("QSpot/enableScrobbling",ENABLE_SCROBBLING_DEFAULT).toInt())
     {
         //scrobbling enabled, send authentication request in order to retrieve a Last.fm session key
@@ -412,7 +436,7 @@ void MainWindow::OnPlaylistContainersReady(QList<Spotify::Playlist*> playlists)
 
    m_pTimeoutTimer->stop(); //stop timeout timer
 
-   iconMap.load("/usr/share/images/icon-type-list.png"); //load playlist type icon from file
+   iconMap.load("/opt/qspot/images/icon-type-list.png"); //load playlist type icon from file
 
    QIcon listTypeIcon(iconMap);
 
@@ -451,6 +475,13 @@ void MainWindow::setupInitialState()
     m_SearchInput.setFocus(); //set initial (default) focus to the Search input field
     m_SearchBtn.setDisabled(false);
 
+    //headset related settings
+    if(m_pAppSettings->value("QSpot/pauseOnHsetUnplugged",PAUSE_ON_HEADSET_UNPLUG_DEFAULT).toInt())
+        m_pQueueView->setPauseOnHSUnplugged(true);
+    else
+        m_pQueueView->setPauseOnHSUnplugged(false);
+
+    //scrobbling settings
     m_pSession->setMinBufferSize(m_pAppSettings->value("QSpot/minBufferLen",MIN_BUFFER_LEN_DEFAULT).toInt()); //update min. buffer length (default to 30 secs)
     if(m_pAppSettings->value("QSpot/enableScrobbling",ENABLE_SCROBBLING_DEFAULT).toInt())
     {
@@ -648,12 +679,16 @@ void MainWindow::OnOrientationChanged()
     if (screenGeometry.width() > screenGeometry.height())
     {
         //switch to landscape mode
+        m_currOrientation = LANDSCAPE_ORIENTATION;
         m_NowPlayingInfo.setFixedWidth(510);
+        m_AboutDlg.setFixedSize(APP_WIDTH,APP_HEIGHT); //resize dialog to fixed size
     }
     else
     {
         //switch to portrait mode
+        m_currOrientation = PORTRAIT_ORIENTATION;
         m_NowPlayingInfo.setFixedWidth(180);
+        m_AboutDlg.setFixedSize(APP_HEIGHT,APP_WIDTH); //resize dialog to fixed size
     }
 }
 
@@ -673,5 +708,27 @@ void MainWindow::OnDisplayStateChanged(bool state)
         m_update = false; //no UI updates
         //disable spectrum analyzer etc.
         m_pSpectrum->Stop();
+        m_currSysVolume = m_pDBusWrapper->getVolume(); //store the current system volume
+    }
+}
+
+void MainWindow::OnHWZoomKeyPressed(quint32 keycode)
+{
+    //notification that HW zoom key has been pressed
+
+    if(m_update) //screen unlocked, return directly
+        return;
+
+    if(((keycode == MM_KEY_DOWN) && m_currOrientation == LANDSCAPE_ORIENTATION)||
+       ((keycode == MM_KEY_UP) && m_currOrientation == PORTRAIT_ORIENTATION))
+    {
+        if(m_currSysVolume<100)
+            m_pDBusWrapper->setVolume(m_currSysVolume++); //set new system volume value
+    }
+    else if(((keycode == MM_KEY_UP) && m_currOrientation == LANDSCAPE_ORIENTATION)|| //landscape
+            ((keycode == MM_KEY_DOWN) && m_currOrientation == PORTRAIT_ORIENTATION)) //portrait
+    {
+        if(m_currSysVolume>0)
+            m_pDBusWrapper->setVolume(m_currSysVolume--); //set new system volume value
     }
 }
