@@ -31,16 +31,18 @@
 #include "AlbumView.h"
 #include "QueueView.h"
 #include "artistview.h"
+#include "AboutDialog.h"
 #include "SpectrumAnalyzer.h"
 #include "customlabel.h"
 #include "OssoWrapper.h"
 #include "lastfmscrobbler.h"
-#include "MCEWrapper.h"
+#include "DBusWrapper.h"
+#include "global_defs.h"
 
 
 //defines
 
-#define APP_VERSION "0.8.1-1" //application version string
+#define APP_VERSION "0.9.0-3" //application version string
 
 class MainWindow : public QMainWindow
 {
@@ -79,7 +81,7 @@ private:
 
     OssoWrapper* m_pOssoWrapper; //wrapper instance for libosso
 
-    MCEWrapper* m_pMCEWrapper; //wrapper instance for MCE D-bus interface
+    DBusWrapper* m_pDBusWrapper; //wrapper instance for D-bus interface
 
     LastFMScrobbler* m_pLastFMScrobbler; //Last.fm scrobbling instance
 
@@ -119,12 +121,16 @@ private:
 
     qint64 m_currPlaybackPos; //playback position for currently playing track
 
-    QMessageBox m_AboutDlg; //App About dialog instance
+    AboutDialog m_AboutDlg; //App About dialog instance
 
     QTimer *m_pTimeoutTimer; //timer used for detecting timeouts (i.e., during playlist loading)
 
     bool m_AudioInit; //TRUE in case audio playback thread initialised
 
+    quint32 m_currSysVolume; //current system volume (used for volume control using HW zoom keys when screen is in locked state)
+
+    qint32 m_currOrientation; //current display orientation
+
     void logout(); //logout current user and display the login dialog
 
     void initAboutDialog(); //setup the application about dialog
@@ -161,6 +167,7 @@ private slots:
      void OnScrobbleTrack(); //scrobble current track to Last.fm (and send scrobbles in queue)
      void OnOrientationChanged(); //device orientation changed (e.g, screen rotate)
      void OnDisplayStateChanged(bool state); //display state changed notification (i.e., true=ON, false=OFF)
+     void OnHWZoomKeyPressed(quint32 keycode); //notification that HW zoom key has been pressed
 
 signals:
 
